@@ -634,7 +634,7 @@ flm.test=function(X.fdata,Y,beta0.fdata=NULL,B=5000,est.method="pls",
 	names(pcvm)="PCvM statistic"
 	result=structure(list(statistic=pcvm,boot.statistics=pcvm.star,p.value=pvalue,method=meth,B=B,type.basis=type.basis,beta.est=beta.est,p=p.opt,ord=ord.opt,data.name="Y=<X,b>+e"))
 							
-	class(result)="htest"
+	class(result) <- "htest"
 	return(result)
 
 }
