@@ -281,9 +281,9 @@ else {
        coefficients<-cbind(b.est,std.error,t.value,p.value)
        colnames(coefficients) <- c("Estimate", "Std. Error", "t value", "Pr(>|t|)")
        rownames(coefficients)[1]="(Intercept)"
-       class(object.lm)<-"lm"
-b.est=b.est[-1]
-names(b.est)<-rownames(coefficients)[-1]
+       class(object.lm) <- "lm"
+	   b.est <- b.est[-1]
+	   names(b.est) <- rownames(coefficients)[-1]
      }
     #  GCV <- sum(e^2)/(n - df)^2      #GCV"=GCV,
 
@@ -292,7 +292,6 @@ out<-list("call"=call,coefficients=coefficients,"residuals"=e,"fitted.values"=yp
 ,"beta.est"=beta.est,weights= weights,"df"=df,"r2"=r2,"sr2"=sr2,"Vp"=Vp,"H"=S,"y"=y,"fdataobj"=fdataobj,
   x.fd=x.fd,"basis.x.opt"=basis.x,"basis.b.opt"=basis.b,"J"=J,"lambda.opt"=lambda,P=R, Lfdobj=Lfdobj,
   lm=object.lm,"mean"=xmean, "b.est"=b.est,"a.est"=a.est,XX=XX)
-
- class(out)="fregre.fd"
+class(out) <- "fregre.fd"
 return(out)
 }
